@@ -3,5 +3,5 @@ pub mod gen_tensor;
 pub mod cuda_tensor;
 #[cfg(feature = "use-cuda")]
 pub mod cuda_helper;
-#[cfg(feature = "use-blas")]
+#[cfg(feature = "use-blas-lapack")]
 pub mod lapack_tensor;
